@@ -26,12 +26,12 @@
 #include "config.h"
 
 #include <assert.h>
-#include <stdlib.h>
 #include <stdint.h>
+#include <stdlib.h>
 
+#include "filter-private.h"
 #include "filter.h"
 #include "libinput-util.h"
-#include "filter-private.h"
 
 /* Trackpoint acceleration for the Lenovo x230. DO NOT TOUCH.
  * This code is only invoked on the X230 and is quite flimsy,
@@ -45,13 +45,13 @@
  * Default parameters for pointer acceleration profiles.
  */
 
-#define DEFAULT_THRESHOLD v_ms2us(0.4)		/* in units/us */
-#define MINIMUM_THRESHOLD v_ms2us(0.2)		/* in units/us */
+#define DEFAULT_THRESHOLD v_usec_from_millis(0.4)		/* in units/us */
+#define MINIMUM_THRESHOLD v_usec_from_millis(0.2)		/* in units/us */
 #define DEFAULT_ACCELERATION 2.0		/* unitless factor */
 #define DEFAULT_INCLINE 1.1			/* unitless factor */
 
 /* for the Lenovo x230 custom accel. do not touch */
-#define X230_THRESHOLD v_ms2us(0.4)		/* in units/us */
+#define X230_THRESHOLD v_usec_from_millis(0.4)		/* in units/us */
 #define X230_ACCELERATION 2.0			/* unitless factor */
 #define X230_INCLINE 1.1			/* unitless factor */
 #define X230_MAGIC_SLOWDOWN 0.4			/* unitless */
@@ -62,14 +62,14 @@ struct pointer_accelerator_x230 {
 
 	accel_profile_func_t profile;
 
-	double velocity;	/* units/us */
-	double last_velocity;	/* units/us */
+	double velocity;      /* units/us */
+	double last_velocity; /* units/us */
 
 	struct pointer_trackers trackers;
 
-	double threshold;	/* units/us */
-	double accel;		/* unitless factor */
-	double incline;		/* incline of the function */
+	double threshold; /* units/us */
+	double accel;     /* unitless factor */
+	double incline;   /* incline of the function */
 
 	int dpi;
 };
@@ -86,7 +86,9 @@ struct pointer_accelerator_x230 {
  */
 static double
 acceleration_profile(struct pointer_accelerator_x230 *accel,
-		     void *data, double velocity, uint64_t time)
+		     void *data,
+		     double velocity,
+		     usec_t time)
 {
 	return accel->profile(&accel->base, data, velocity, time);
 }
@@ -108,7 +110,7 @@ calculate_acceleration(struct pointer_accelerator_x230 *accel,
 		       void *data,
 		       double velocity,
 		       double last_velocity,
-		       uint64_t time)
+		       usec_t time)
 {
 	double factor;
 
@@ -116,10 +118,9 @@ calculate_acceleration(struct pointer_accelerator_x230 *accel,
 	 * the previous motion and the most recent. */
 	factor = acceleration_profile(accel, data, velocity, time);
 	factor += acceleration_profile(accel, data, last_velocity, time);
-	factor += 4.0 *
-		acceleration_profile(accel, data,
-				     (last_velocity + velocity) / 2,
-				     time);
+	factor +=
+		4.0 *
+		acceleration_profile(accel, data, (last_velocity + velocity) / 2, time);
 
 	factor = factor / 6.0;
 
@@ -129,10 +130,11 @@ calculate_acceleration(struct pointer_accelerator_x230 *accel,
 static struct normalized_coords
 accelerator_filter_x230(struct motion_filter *filter,
 			const struct device_float_coords *raw,
-			void *data, uint64_t time)
+			void *data,
+			usec_t time)
 {
 	struct pointer_accelerator_x230 *accel =
-		(struct pointer_accelerator_x230 *) filter;
+		(struct pointer_accelerator_x230 *)filter;
 	double accel_factor; /* unitless factor */
 	struct normalized_coords accelerated;
 	struct device_float_coords delta_normalized;
@@ -168,13 +170,13 @@ accelerator_filter_x230(struct motion_filter *filter,
 static struct normalized_coords
 accelerator_filter_constant_x230(struct motion_filter *filter,
 				 const struct device_float_coords *unaccelerated,
-				 void *data, uint64_t time)
+				 void *data,
+				 usec_t time)
 {
 	struct pointer_accelerator_x230 *accel =
-		(struct pointer_accelerator_x230 *) filter;
+		(struct pointer_accelerator_x230 *)filter;
 	struct normalized_coords normalized;
-	const double factor =
-		X230_MAGIC_SLOWDOWN/X230_TP_MAGIC_LOW_RES_FACTOR;
+	const double factor = X230_MAGIC_SLOWDOWN / X230_TP_MAGIC_LOW_RES_FACTOR;
 
 	normalized = normalize_for_dpi(unaccelerated, accel->dpi);
 	normalized.x = factor * normalized.x;
@@ -183,19 +185,38 @@ accelerator_filter_constant_x230(struct motion_filter *filter,
 	return normalized;
 }
 
+static struct normalized_coords
+accelerator_filter_scroll_x230(struct motion_filter *filter,
+			       const struct device_float_coords *unaccelerated,
+			       void *data,
+			       usec_t time,
+			       enum filter_scroll_type type)
+{
+	/* Scroll wheels were not historically accelerated and have different
+	 * units than button scrolling. Maintain the status quo and do not
+	 * accelerate wheel events.
+	 */
+	if (type == FILTER_SCROLL_TYPE_WHEEL) {
+		return (struct normalized_coords){
+			.x = unaccelerated->x,
+			.y = unaccelerated->y,
+		};
+	}
+
+	return accelerator_filter_constant_x230(filter, unaccelerated, data, time);
+}
+
 static void
-accelerator_restart_x230(struct motion_filter *filter,
-			 void *data,
-			 uint64_t time)
+accelerator_restart_x230(struct motion_filter *filter, void *data, usec_t time)
 {
 	struct pointer_accelerator_x230 *accel =
-		(struct pointer_accelerator_x230 *) filter;
+		(struct pointer_accelerator_x230 *)filter;
 	unsigned int offset;
 	struct pointer_tracker *tracker;
 
 	for (offset = 1; offset < accel->trackers.ntrackers; offset++) {
 		tracker = trackers_by_offset(&accel->trackers, offset);
-		tracker->time = 0;
+		tracker->time = usec_from_uint64_t(0);
 		tracker->dir = 0;
 		tracker->delta.x = 0;
 		tracker->delta.y = 0;
@@ -210,15 +231,14 @@ static void
 accelerator_destroy_x230(struct motion_filter *filter)
 {
 	struct pointer_accelerator_x230 *accel =
-		(struct pointer_accelerator_x230 *) filter;
+		(struct pointer_accelerator_x230 *)filter;
 
 	free(accel->trackers.trackers);
 	free(accel);
 }
 
 static bool
-accelerator_set_speed_x230(struct motion_filter *filter,
-			   double speed_adjustment)
+accelerator_set_speed_x230(struct motion_filter *filter, double speed_adjustment)
 {
 	struct pointer_accelerator_x230 *accel_filter =
 		(struct pointer_accelerator_x230 *)filter;
@@ -229,8 +249,8 @@ accelerator_set_speed_x230(struct motion_filter *filter,
 	   don't read more into them other than "they mostly worked ok" */
 
 	/* delay when accel kicks in */
-	accel_filter->threshold = DEFAULT_THRESHOLD -
-					v_ms2us(0.25) * speed_adjustment;
+	accel_filter->threshold =
+		DEFAULT_THRESHOLD - v_usec_from_millis(0.25) * speed_adjustment;
 	if (accel_filter->threshold < MINIMUM_THRESHOLD)
 		accel_filter->threshold = MINIMUM_THRESHOLD;
 
@@ -246,9 +266,9 @@ accelerator_set_speed_x230(struct motion_filter *filter,
 
 double
 touchpad_lenovo_x230_accel_profile(struct motion_filter *filter,
-				      void *data,
-				      double speed_in, /* 1000dpi-units/µs */
-				      uint64_t time)
+				   void *data,
+				   double speed_in, /* 1000dpi-units/µs */
+				   usec_t time)
 {
 	/* Those touchpads presents an actual lower resolution that what is
 	 * advertised. We see some jumps from the cursor due to the big steps
@@ -262,9 +282,9 @@ touchpad_lenovo_x230_accel_profile(struct motion_filter *filter,
 
 	double f1, f2; /* unitless */
 	const double max_accel = accel_filter->accel *
-				  X230_TP_MAGIC_LOW_RES_FACTOR; /* unitless factor */
-	const double threshold = accel_filter->threshold /
-				  X230_TP_MAGIC_LOW_RES_FACTOR; /* units/us */
+				 X230_TP_MAGIC_LOW_RES_FACTOR; /* unitless factor */
+	const double threshold =
+		accel_filter->threshold / X230_TP_MAGIC_LOW_RES_FACTOR; /* units/us */
 	const double incline = accel_filter->incline * X230_TP_MAGIC_LOW_RES_FACTOR;
 
 	/* Note: the magic values in this function are obtained by
@@ -287,7 +307,7 @@ static const struct motion_filter_interface accelerator_interface_x230 = {
 	.type = LIBINPUT_CONFIG_ACCEL_PROFILE_ADAPTIVE,
 	.filter = accelerator_filter_x230,
 	.filter_constant = accelerator_filter_constant_x230,
-	.filter_scroll = accelerator_filter_constant_x230,
+	.filter_scroll = accelerator_filter_scroll_x230,
 	.restart = accelerator_restart_x230,
 	.destroy = accelerator_destroy_x230,
 	.set_speed = accelerator_set_speed_x230,
@@ -311,7 +331,7 @@ create_pointer_accelerator_filter_lenovo_x230(int dpi, bool use_velocity_averagi
 
 	filter->threshold = X230_THRESHOLD;
 	filter->accel = X230_ACCELERATION; /* unitless factor */
-	filter->incline = X230_INCLINE; /* incline of the acceleration function */
+	filter->incline = X230_INCLINE;    /* incline of the acceleration function */
 	filter->dpi = dpi;
 
 	return &filter->base;
